@@ -1,24 +1,11 @@
 # -*- coding: utf-8 -*-
-# pytils - russian-specific string utils
-# Copyright (C) 2006-2008  Yury Yurevich
-#
-# http://www.pyobject.ru/projects/pytils/
-#
-# This program is free software; you can redistribute it and/or
-# modify it under the terms of the GNU General Public License
-# as published by the Free Software Foundation, version 2
-# of the License.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
 """
 Unit tests for pytils
 """
-__all__ = ["test_numeral", "test_dt", "test_translit", "test_utils"]
+__all__ = ["test_numeral", "test_dt", "test_translit", "test_utils", "test_typo"]
 
 import unittest
+import sys
 
 def get_django_suite():
     try:
@@ -54,7 +41,9 @@ def run_tests_from_module(module, verbosity=1):
 def run(verbosity=1):
     """Run all unit-test of pytils"""
     suite = get_suite()
-    unittest.TextTestRunner(verbosity=verbosity).run(suite)
+    res = unittest.TextTestRunner(verbosity=verbosity).run(suite)
+    if res.errors or res.failures:
+        sys.exit(1)
 
 if __name__ == '__main__':
     run(2)
