@@ -1,23 +1,10 @@
 # -*- coding: utf-8 -*-
-# pytils - russian-specific string utils
-# Copyright (C) 2006-2008  Yury Yurevich
-#
-# http://www.pyobject.ru/projects/pytils/
-#
-# This program is free software; you can redistribute it and/or
-# modify it under the terms of the GNU General Public License
-# as published by the Free Software Foundation, version 2
-# of the License.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
 """
 Helpers for templatetags' unit tests in Django webframework
 """
 
 from django.conf import settings
+from django.utils.encoding import smart_str
 
 encoding = 'utf-8'
 
@@ -31,16 +18,10 @@ settings.configure(
 
 from django import template
 from django.template import loader
-from pytils.templatetags import pseudo_str
 
 import unittest
 
 
-def pstr(ustr):
-    """
-    Provide/Pseudo unicode
-    """
-    return pseudo_str(ustr, encoding, None)
 
 
 class TemplateTagTestCase(unittest.TestCase):
@@ -65,10 +46,10 @@ class TemplateTagTestCase(unittest.TestCase):
         """
         
         def test_template_loader(template_name, template_dirs=None):
-            return pstr(template_string), template_name
+            return smart_str(template_string), template_name
         
         loader.template_source_loaders = [test_template_loader,]
         
         output = loader.get_template(template_name).render(template.Context(context))
-        self.assertEquals(output, pstr(result_string))
+        self.assertEquals(output, result_string)
 
