@@ -1,25 +1,20 @@
 # -*- coding: utf-8 -*-
-# pytils - russian-specific string utils
-# Copyright (C) 2006-2008  Yury Yurevich
-#
-# http://www.pyobject.ru/projects/pytils/
-#
-# This program is free software; you can redistribute it and/or
-# modify it under the terms of the GNU General Public License
-# as published by the Free Software Foundation, version 2
-# of the License.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
 """
 Unit-tests for pytils.numeral
 """
 
 import unittest
+import decimal
 import pytils
 
+# Python3 doesn't have long type
+# it has only int
+from pytils.third import six
+
+if six.PY3:
+    long = int
+
+
 class ChoosePluralTestCase(unittest.TestCase):
     """
     Test case for pytils.numeral.choose_plural
@@ -48,24 +43,21 @@ class ChoosePluralTestCase(unittest.TestCase):
         self.checkChoosePlural(5, u"гвоздей")
         self.checkChoosePlural(11, u"гвоздей")
         self.checkChoosePlural(109, u"гвоздей")
-        self.checkChoosePlural(109l, u"гвоздей")
+        self.checkChoosePlural(long(109), u"гвоздей")
+
+    def testChoosePluralNegativeBug9(self):
+        """
+        Test handling of negative numbers
+        """
+        self.checkChoosePlural(-5, u"гвоздей")
+        self.checkChoosePlural(-2, u"гвоздя")
 
     def testChoosePluralExceptions(self):
         """
         Unit-test for testing choos_plural's exceptions
         """
-        self.assertRaises(TypeError, pytils.numeral.choose_plural,
-                          "25", u"any,bene,raba")
-        self.assertRaises(TypeError, pytils.numeral.choose_plural,
-                          25, 30)
-        self.assertRaises(pytils.err.InputParameterError, pytils.numeral.choose_plural,
-                          "25", u"any,bene,raba")
-        self.assertRaises(pytils.err.InputParameterError, pytils.numeral.choose_plural,
-                          25, 30)
         self.assertRaises(ValueError, pytils.numeral.choose_plural,
                           25, u"any,bene")
-        self.assertRaises(ValueError, pytils.numeral.choose_plural,
-                          -25, u"any,bene,raba")
 
     def testChoosePluralVariantsInStr(self):
         """
@@ -132,7 +124,7 @@ class GetFloatRemainderTestCase(unittest.TestCase):
     def testFloatRemainder(self):
         """
         Unit-test for _get_float_remainder
-        """        
+        """
         self.assertEquals(pytils.numeral._get_float_remainder(1.3),
                           '3')
         self.assertEquals(pytils.numeral._get_float_remainder(2.35, 1),
@@ -146,14 +138,30 @@ class GetFloatRemainderTestCase(unittest.TestCase):
         self.assertEquals(pytils.numeral._get_float_remainder(5),
                           '0')
 
+    def testFloatRemainderDecimal(self):
+        """
+        Unit-test for _get_float_remainder with decimal type
+        """
+        D = decimal.Decimal
+        self.assertEquals(pytils.numeral._get_float_remainder(D("1.3")),
+                          '3')
+        self.assertEquals(pytils.numeral._get_float_remainder(D("2.35"), 1),
+                          '4')
+        self.assertEquals(pytils.numeral._get_float_remainder(D("123.1234567891")),
+                          '123456789')
+        self.assertEquals(pytils.numeral._get_float_remainder(D("2.353"), 2),
+                          '35')
+        self.assertEquals(pytils.numeral._get_float_remainder(D("0.01")),
+                          '01')
+        self.assertEquals(pytils.numeral._get_float_remainder(D("5")),
+                          '0')
+
     def testFloatRemainderExceptions(self):
         """
         Unit-test for testing _get_float_remainder's exceptions
         """
         self.assertRaises(ValueError, pytils.numeral._get_float_remainder,
                           2.998, 2)
-        self.assertRaises(TypeError, pytils.numeral._get_float_remainder, "1.23")
-        self.assertRaises(pytils.err.InputParameterError, pytils.numeral._get_float_remainder, "1.23")
         self.assertRaises(ValueError, pytils.numeral._get_float_remainder, -1.23)
 
 class RublesTestCase(unittest.TestCase):
@@ -164,7 +172,7 @@ class RublesTestCase(unittest.TestCase):
     def testRubles(self):
         """
         Unit-test for rubles
-        """        
+        """
         self.assertEquals(pytils.numeral.rubles(10.01),
                           u"десять рублей одна копейка")
         self.assertEquals(pytils.numeral.rubles(10.10),
@@ -177,15 +185,29 @@ class RublesTestCase(unittest.TestCase):
                           u"три рубля")
         self.assertEquals(pytils.numeral.rubles(3, True),
                           u"три рубля ноль копеек")
-        self.assertEquals(pytils.numeral.rubles(3l),
+        self.assertEquals(pytils.numeral.rubles(long(3)),
                           u"три рубля")
 
+    def testRublesDecimal(self):
+        """
+        Test for rubles with decimal instead of float/integer
+        """
+        D = decimal.Decimal
+        self.assertEquals(pytils.numeral.rubles(D("10.01")),
+                          u"десять рублей одна копейка")
+        self.assertEquals(pytils.numeral.rubles(D("10.10")),
+                          u"десять рублей десять копеек")
+        self.assertEquals(pytils.numeral.rubles(D("2.35")),
+                          u"два рубля тридцать пять копеек")
+        self.assertEquals(pytils.numeral.rubles(D(3)),
+                          u"три рубля")
+        self.assertEquals(pytils.numeral.rubles(D(3), True),
+                          u"три рубля ноль копеек")
+
     def testRublesExceptions(self):
         """
         Unit-test for testing rubles' exceptions
         """
-        self.assertRaises(TypeError, pytils.numeral.rubles, "3")
-        self.assertRaises(pytils.err.InputParameterError, pytils.numeral.rubles, "3")
         self.assertRaises(ValueError, pytils.numeral.rubles, -15)
         
 
@@ -197,7 +219,7 @@ class InWordsTestCase(unittest.TestCase):
     def testInt(self):
         """
         Unit-test for in_words_int
-        """                
+        """
         self.assertEquals(pytils.numeral.in_words_int(10), u"десять")
         self.assertEquals(pytils.numeral.in_words_int(5), u"пять")
         self.assertEquals(pytils.numeral.in_words_int(102), u"сто два")
@@ -207,20 +229,18 @@ class InWordsTestCase(unittest.TestCase):
                           u"три тысячи пятьсот")
         self.assertEquals(pytils.numeral.in_words_int(5231000),
                           u"пять миллионов двести тридцать одна тысяча")
-        self.assertEquals(pytils.numeral.in_words_int(10l), u"десять")
+        self.assertEquals(pytils.numeral.in_words_int(long(10)), u"десять")
 
     def testIntExceptions(self):
         """
         Unit-test for testing in_words_int's exceptions
         """
-        self.assertRaises(TypeError, pytils.numeral.in_words_int, 2.5)
-        self.assertRaises(pytils.err.InputParameterError, pytils.numeral.in_words_int, 2.5)
         self.assertRaises(ValueError, pytils.numeral.in_words_int, -3)
 
     def testFloat(self):
         """
         Unit-test for in_words_float
-        """                
+        """
         self.assertEquals(pytils.numeral.in_words_float(10.0),
                           u"десять целых ноль десятых")
         self.assertEquals(pytils.numeral.in_words_float(2.25),
@@ -230,15 +250,28 @@ class InWordsTestCase(unittest.TestCase):
         self.assertEquals(pytils.numeral.in_words_float(0.10),
                           u"ноль целых одна десятая")
 
+    def testDecimal(self):
+        """
+        Unit-test for in_words_float with decimal type
+        """
+        D = decimal.Decimal
+        self.assertEquals(pytils.numeral.in_words_float(D("10.0")),
+                          u"десять целых ноль десятых")
+        self.assertEquals(pytils.numeral.in_words_float(D("2.25")),
+                          u"две целых двадцать пять сотых")
+        self.assertEquals(pytils.numeral.in_words_float(D("0.01")),
+                          u"ноль целых одна сотая")
+        # поскольку это Decimal, то здесь нет незначащих нулей
+        # т.е. нули определяют точность, поэтому десять сотых,
+        # а не одна десятая
+        self.assertEquals(pytils.numeral.in_words_float(D("0.10")),
+                          u"ноль целых десять сотых")
+
     def testFloatExceptions(self):
         """
         Unit-test for testing in_words_float's exceptions
         """
-        self.assertRaises(TypeError, pytils.numeral.in_words_float, '2')
-        self.assertRaises(TypeError, pytils.numeral.in_words_float, 2)
-        self.assertRaises(pytils.err.InputParameterError, pytils.numeral.in_words_float, '2')
-        self.assertRaises(pytils.err.InputParameterError, pytils.numeral.in_words_float, 2)
-        self.assertRaises(ValueError, pytils.numeral.in_words_float, -2.3)        
+        self.assertRaises(ValueError, pytils.numeral.in_words_float, -2.3)
 
     def testWithGenderOldStyle(self):
         """
@@ -257,7 +290,7 @@ class InWordsTestCase(unittest.TestCase):
                           u"двадцать одна целая ноль десятых")
         self.assertEquals(pytils.numeral.in_words(21.0, 3),
                           u"двадцать одна целая ноль десятых")
-        self.assertEquals(pytils.numeral.in_words(21l, 1),
+        self.assertEquals(pytils.numeral.in_words(long(21), 1),
                           u"двадцать один")
 
     def testWithGender(self):
@@ -277,14 +310,15 @@ class InWordsTestCase(unittest.TestCase):
                           u"двадцать одна целая ноль десятых")
         self.assertEquals(pytils.numeral.in_words(21.0, pytils.numeral.NEUTER),
                           u"двадцать одна целая ноль десятых")
-        self.assertEquals(pytils.numeral.in_words(21l, pytils.numeral.MALE),
+        self.assertEquals(pytils.numeral.in_words(long(21), pytils.numeral.MALE),
                           u"двадцать один")
 
 
     def testCommon(self):
         """
         Unit-test for general in_words
-        """                
+        """
+        D = decimal.Decimal
         self.assertEquals(pytils.numeral.in_words(10), u"десять")
         self.assertEquals(pytils.numeral.in_words(5), u"пять")
         self.assertEquals(pytils.numeral.in_words(102), u"сто два")
@@ -302,20 +336,22 @@ class InWordsTestCase(unittest.TestCase):
                           u"ноль целых одна сотая")
         self.assertEquals(pytils.numeral.in_words(0.10),
                           u"ноль целых одна десятая")
-        self.assertEquals(pytils.numeral.in_words(10l), u"десять")
+        self.assertEquals(pytils.numeral.in_words(long(10)), u"десять")
+        self.assertEquals(pytils.numeral.in_words(D("2.25")),
+                          u"две целых двадцать пять сотых")
+        self.assertEquals(pytils.numeral.in_words(D("0.01")),
+                          u"ноль целых одна сотая")
+        self.assertEquals(pytils.numeral.in_words(D("0.10")),
+                          u"ноль целых десять сотых")
+        self.assertEquals(pytils.numeral.in_words(D("10")), u"десять")
 
     def testCommonExceptions(self):
         """
         Unit-test for testing in_words' exceptions
         """
-        self.assertRaises(TypeError, pytils.numeral.in_words, "0.2")
-        self.assertRaises(TypeError, pytils.numeral.in_words, 0.2, "1")
-        self.assertRaises(TypeError, pytils.numeral.in_words, 0.2, 5)
-        self.assertRaises(pytils.err.InputParameterError, pytils.numeral.in_words, "0.2")
-        self.assertRaises(pytils.err.InputParameterError, pytils.numeral.in_words, 0.2, "1")
-        self.assertRaises(pytils.err.InputParameterError, pytils.numeral.in_words, 0.2, 5)
         self.assertRaises(ValueError, pytils.numeral.in_words, -2)
-        
+        self.assertRaises(ValueError, pytils.numeral.in_words, -2.5)
+
 
 class SumStringTestCase(unittest.TestCase):
     """
@@ -377,7 +413,7 @@ class SumStringTestCase(unittest.TestCase):
         self.ckFemaleOldStyle(2, u"две шляпки")
         self.ckFemaleOldStyle(31, u"тридцать одна шляпка")
         
-        self.ckFemaleOldStyle(31l, u"тридцать одна шляпка")
+        self.ckFemaleOldStyle(long(31), u"тридцать одна шляпка")
 
         self.assertEquals(u"одиннадцать негритят",
                           pytils.numeral.sum_string(
@@ -397,7 +433,7 @@ class SumStringTestCase(unittest.TestCase):
         self.ckFemale(2, u"две шляпки")
         self.ckFemale(31, u"тридцать одна шляпка")
         
-        self.ckFemale(31l, u"тридцать одна шляпка")
+        self.ckFemale(long(31), u"тридцать одна шляпка")
 
         self.assertEquals(u"одиннадцать негритят",
                           pytils.numeral.sum_string(
@@ -410,26 +446,6 @@ class SumStringTestCase(unittest.TestCase):
         """
         Unit-test for testing sum_string's exceptions
         """
-        self.assertRaises(TypeError, pytils.numeral.sum_string,
-                                      "1", 1)
-        self.assertRaises(TypeError, pytils.numeral.sum_string,
-                                      1, "1")
-        self.assertRaises(TypeError, pytils.numeral.sum_string,
-                                      1, "1", 23)
-        self.assertRaises(TypeError, pytils.numeral.sum_string,
-                                      1, pytils.numeral.MALE, (23,24,25))
-        self.assertRaises(TypeError, pytils.numeral.sum_string,
-                                      1, pytils.numeral.MALE, (23,))
-        self.assertRaises(pytils.err.InputParameterError, pytils.numeral.sum_string,
-                                      "1", 1)
-        self.assertRaises(pytils.err.InputParameterError, pytils.numeral.sum_string,
-                                      1, "1")
-        self.assertRaises(pytils.err.InputParameterError, pytils.numeral.sum_string,
-                                      1, "1", 23)
-        self.assertRaises(pytils.err.InputParameterError, pytils.numeral.sum_string,
-                                      1, pytils.numeral.MALE, (23,24,25))
-        self.assertRaises(pytils.err.InputParameterError, pytils.numeral.sum_string,
-                                      1, pytils.numeral.MALE, (23,))
         self.assertRaises(ValueError, pytils.numeral.sum_string,
                                       -1, pytils.numeral.MALE, u"any,bene,raba")
 
